Renamed shortPath to simplePath
authorMarc MAURICE <dooblempub@positon.org>
Thu, 30 Dec 2010 16:49:51 +0000 (17:49 +0100)
committerMarc MAURICE <dooblempub@positon.org>
Thu, 30 Dec 2010 16:49:51 +0000 (17:49 +0100)
index.php
plugins/viewer/view.php

index 38e2a9b..337e96f 100644 (file)
--- a/index.php
+++ b/index.php
@@ -108,12 +108,12 @@ if (! isset($_SERVER["PATH_INFO"])) {
        exit();
 }
 
-# shortPath is the simple path to the image
-# /index.php/toto/titi => shortPath == /toto/titi
-$shortPath = $_SERVER["PATH_INFO"];
-if ($shortPath == '/') $shortPath = '';
+# simplePath is the simple path to the image
+# /index.php/toto/titi => simplePath == /toto/titi
+$simplePath = $_SERVER["PATH_INFO"];
+if ($simplePath == '/') $simplePath = '';
 // extra security check to avoid /photos/index/../.. like urls, maybe useless but..
-if (strpos($shortPath, '..') !== false) die(".. found in url");
+if (strpos($simplePath, '..') !== false) die(".. found in url");
 
 $folders = array();
 $imageFiles = array();
@@ -121,7 +121,7 @@ $otherFiles = array();
 
 # realDir is the directory in filesystem
 # seen from current script directory
-$realDir = IMAGES_DIR.$shortPath;
+$realDir = IMAGES_DIR.$simplePath;
 
 if (! is_dir($realDir)) {
        header("HTTP/1.1 404 Not Found");
@@ -132,21 +132,21 @@ foreach (scandir($realDir) as $file) if ($file != '.' and $file != '..')
 {
        if (is_dir("$realDir/$file"))
        {
-               $folders[] = array( "name" => $file, "link" => "$scriptUrlPath$shortPath/$file", "preview" => getAlbumPreview("$realDir/$file") );
+               $folders[] = array( "name" => $file, "link" => "$scriptUrlPath$simplePath/$file", "preview" => getAlbumPreview("$realDir/$file") );
        }
        else
        {
                $ext = strtolower(substr($file, -4));
                if ($ext == ".jpg" or $ext == ".png") {
-                       $imageFiles[] = array( "name" => $file, "url" => getPreview("$realDir/$file"), "link" => getImageLink("$shortPath/$file") );
+                       $imageFiles[] = array( "name" => $file, "url" => getPreview("$realDir/$file"), "link" => getImageLink("$simplePath/$file") );
                } else {
                        $otherFiles[] = array( "name" => $file, "link" => dirname($scriptUrlPath)."/$realDir/$file" );
                }
        }
 }
 
-if (dirname($shortPath) !== '')
-       $parentLink = $scriptUrlPath.dirname($shortPath);
+if (dirname($simplePath) !== '')
+       $parentLink = $scriptUrlPath.dirname($simplePath);
 else
        $parentLink = "";
 
index cdc5f12..56fcf11 100644 (file)
 
 require '../../config.php';
 
-$shortPath = $_SERVER["PATH_INFO"];
-if ($shortPath == '/') $shortPath = '';
+$simplePath = $_SERVER["PATH_INFO"];
+if ($simplePath == '/') $simplePath = '';
 // extra security check to avoid /photos/index/../.. like urls, maybe useless but..
-if (strpos($shortPath, '..') !== false) die(".. found in url");
+if (strpos($simplePath, '..') !== false) die(".. found in url");
 
-if (! is_file('../../'.IMAGES_DIR.$shortPath)) {
+if (! is_file('../../'.IMAGES_DIR.$simplePath)) {
        header("HTTP/1.1 404 Not Found");
        die("File Not Found");
 }
@@ -34,7 +34,7 @@ $scriptPath = $_SERVER["SCRIPT_NAME"];
 // get all images in an array
 $images = array();
 
-$files = scandir('../../'.IMAGES_DIR.dirname($shortPath));
+$files = scandir('../../'.IMAGES_DIR.dirname($simplePath));
 foreach ($files as $file) {
        $ext = strtolower(substr($file, -4));
        if ($ext == ".jpg" or $ext == ".png")
@@ -42,7 +42,7 @@ foreach ($files as $file) {
 }
 
 // find the image position
-$pos = array_search(basename($shortPath), $images);
+$pos = array_search(basename($simplePath), $images);
 if ($pos === false) die("Image not found");
 
 // get prev and next images
@@ -54,19 +54,19 @@ if ($pos < sizeof($images)-1)
        $nextImage = $images[$pos+1];
 
 // template variables
-$imageUrl = dirname($scriptPath)."/../../".IMAGES_DIR.$shortPath;
+$imageUrl = dirname($scriptPath)."/../../".IMAGES_DIR.$simplePath;
 
 if ($nextImage === '') {
        $nextImageUrl = '';
        $nextPageUrl = '';
 } else {
-       $nextImageUrl = dirname($scriptPath)."/".IMAGES_DIR.dirname($shortPath)."/$nextImage";
+       $nextImageUrl = dirname($scriptPath)."/".IMAGES_DIR.dirname($simplePath)."/$nextImage";
        $nextPageUrl = dirname($_SERVER["REQUEST_URI"])."/$nextImage";
 }
 if ($prevImage === '') $prevPageUrl = '';
 else $prevPageUrl = dirname($_SERVER["REQUEST_URI"])."/$prevImage";
 
-$directoryUrl = dirname($scriptPath)."/../../index.php".dirname($shortPath);
+$directoryUrl = dirname($scriptPath)."/../../index.php".dirname($simplePath);
 
 header('Content-Type: text/html; charset=utf-8');
 header('Expires: '.gmdate('D, d M Y H:i:s \G\M\T', time() + 3600));